summaryrefslogtreecommitdiff
path: root/webpack.config.ts
diff options
context:
space:
mode:
authorAkihiko Odaki <nekomanma@pixiv.co.jp>2018-03-29 01:20:40 +0900
committerAkihiko Odaki <nekomanma@pixiv.co.jp>2018-03-29 01:54:41 +0900
commit90f8fe7e538bb7e52d2558152a0390e693f39b11 (patch)
tree0f830887053c8f352b1cd0c13ca715fd14c1f030 /webpack.config.ts
parentImplement remote account resolution (diff)
downloadmisskey-90f8fe7e538bb7e52d2558152a0390e693f39b11.tar.gz
misskey-90f8fe7e538bb7e52d2558152a0390e693f39b11.tar.bz2
misskey-90f8fe7e538bb7e52d2558152a0390e693f39b11.zip
Introduce processor
Diffstat (limited to 'webpack.config.ts')
-rw-r--r--webpack.config.ts30
1 files changed, 15 insertions, 15 deletions
diff --git a/webpack.config.ts b/webpack.config.ts
index 9a952c8ef3..6f16fcbfa3 100644
--- a/webpack.config.ts
+++ b/webpack.config.ts
@@ -11,11 +11,11 @@ const WebpackOnBuildPlugin = require('on-build-webpack');
//const HardSourceWebpackPlugin = require('hard-source-webpack-plugin');
const ProgressBarPlugin = require('progress-bar-webpack-plugin');
-import I18nReplacer from './src/common/build/i18n';
-import { pattern as faPattern, replacement as faReplacement } from './src/common/build/fa';
+import I18nReplacer from './src/build/i18n';
+import { pattern as faPattern, replacement as faReplacement } from './src/build/fa';
const constants = require('./src/const.json');
import config from './src/conf';
-import { licenseHtml } from './src/common/build/license';
+import { licenseHtml } from './src/build/license';
import locales from './locales';
const meta = require('./package.json');
@@ -33,7 +33,7 @@ global['collapseSpacesReplacement'] = html => {
};
global['base64replacement'] = (_, key) => {
- return fs.readFileSync(__dirname + '/src/web/' + key, 'base64');
+ return fs.readFileSync(__dirname + '/src/server/web/' + key, 'base64');
};
//#endregion
@@ -51,18 +51,18 @@ module.exports = entries.map(x => {
// Entries
const entry = {
- desktop: './src/web/app/desktop/script.ts',
- mobile: './src/web/app/mobile/script.ts',
- //ch: './src/web/app/ch/script.ts',
- //stats: './src/web/app/stats/script.ts',
- //status: './src/web/app/status/script.ts',
- dev: './src/web/app/dev/script.ts',
- auth: './src/web/app/auth/script.ts',
- sw: './src/web/app/sw.js'
+ desktop: './src/server/web/app/desktop/script.ts',
+ mobile: './src/server/web/app/mobile/script.ts',
+ //ch: './src/server/web/app/ch/script.ts',
+ //stats: './src/server/web/app/stats/script.ts',
+ //status: './src/server/web/app/status/script.ts',
+ dev: './src/server/web/app/dev/script.ts',
+ auth: './src/server/web/app/auth/script.ts',
+ sw: './src/server/web/app/sw.js'
};
const output = {
- path: __dirname + '/built/web/assets',
+ path: __dirname + '/built/server/web/assets',
filename: `[name].${version}.${lang}.${isProduction ? 'min' : 'raw'}.js`
};
@@ -206,7 +206,7 @@ module.exports = entries.map(x => {
loader: 'ts-loader',
options: {
happyPackMode: true,
- configFile: __dirname + '/../src/web/app/tsconfig.json',
+ configFile: __dirname + '/../src/server/web/app/tsconfig.json',
appendTsSuffixTo: [/\.vue$/]
}
}, {
@@ -231,7 +231,7 @@ module.exports = entries.map(x => {
'.js', '.ts', '.json'
],
alias: {
- 'const.styl': __dirname + '/src/web/const.styl'
+ 'const.styl': __dirname + '/src/server/web/const.styl'
}
},
resolveLoader: {